@@ -79,6 +79,7 @@ INSTALLED_APPS = [
     "django.contrib.messages",
     "django.contrib.staticfiles",
     "django.contrib.sites",
+    "django.contrib.humanize",
     "django_filters",
     "django_extensions",
     'rest_framework.authtoken',
@@ -118,6 +119,8 @@ TEMPLATES = [
                 "django.template.context_processors.request",
                 "django.contrib.auth.context_processors.auth",
                 "django.contrib.messages.context_processors.messages",
+                "videos.context_processors.video_lists",
+                "music.context_processors.music_lists",
             ],
         },
     },
